from vasp_suite.cli import *
"""
This is a package for generating input and submission files for vasp calculations
"""
